@@ -52,8 +52,8 @@ class LocalFsStorageDomainManifest(fileSD.FileStorageDomainManifest):
 class LocalFsStorageDomain(fileSD.FileStorageDomain):
     manifestClass = LocalFsStorageDomainManifest
 
-    supported_block_size = (sc.BLOCK_SIZE_512,)
-    supported_alignment = (sc.ALIGNMENT_1M,)
+    supported_block_size = (
+        sc.BLOCK_SIZE_AUTO, sc.BLOCK_SIZE_512, sc.BLOCK_SIZE_4K)
 
     @property
     def supportsMailbox(self):
@@ -66,7 +66,6 @@ class LocalFsStorageDomain(fileSD.FileStorageDomain):
             raise se.StorageDomainIllegalRemotePath(typeSpecificArg)
 
         fileSD.validateDirAccess(domPath)
-        fileSD.validateFileSystemFeatures(sdUUID, domPath)
 
         sd.validateDomainVersion(version)
 
@@ -78,7 +77,7 @@ class LocalFsStorageDomain(fileSD.FileStorageDomain):
     @classmethod
     def create(cls, sdUUID, domainName, domClass, remotePath, storageType,
                version, block_size=sc.BLOCK_SIZE_512,
-               alignment=sc.ALIGNMENT_1M):
+               max_hosts=sc.HOSTS_4K_1M):
         """
         Create new storage domain
 
@@ -91,15 +90,10 @@ class LocalFsStorageDomain(fileSD.FileStorageDomain):
             version (int): DOMAIN_VERSIONS
             block_size (int): Underlying storage block size.
                 Supported value is BLOCK_SIZE_512
-            alignment (int): Sanlock alignment to use for this storage domain.
-                Supported value is ALIGN_1M
+            max_hosts (int): Maximum number of hosts accessing this domain,
+                default to sc.HOSTS_4K_1M.
         """
-        cls.log.info("sdUUID=%s domainName=%s remotePath=%s "
-                     "domClass=%s, block_size=%s, alignment=%s",
-                     sdUUID, domainName, remotePath, domClass,
-                     block_size, alignment)
-
-        cls._validate_block_and_alignment(block_size, alignment, version)
+        cls._validate_block_size(block_size, version)
 
         if not misc.isAscii(domainName) and not sd.supportsUnicode(version):
             raise se.UnicodeArgumentException()
@@ -111,6 +105,12 @@ class LocalFsStorageDomain(fileSD.FileStorageDomain):
 
         cls._preCreateValidation(sdUUID, mntPoint, remotePath, version)
 
+        storage_block_size = cls._detect_block_size(sdUUID, mntPoint)
+        block_size = cls._validate_storage_block_size(
+            block_size, storage_block_size)
+
+        alignment = clusterlock.alignment(block_size, max_hosts)
+
         domainDir = os.path.join(mntPoint, sdUUID)
         cls._prepareMetadata(domainDir, sdUUID, domainName, domClass,
                              remotePath, storageType, version, alignment,
